#!/bin/sh

if [ "$(id -u)" != "0" ]; then
  echo "Please run this script with root access"
  exit 1
fi

if [ "$(uname -m)" != "x86_64" ]; then
  PLATFORM=32
else
  PLATFORM=64
fi

echo Installing simpson in /usr/local/bin
cp $PLATFORM/simpson /usr/local/bin
chown root:root /usr/local/bin/simpson
chmod 755 /usr/local/bin/simpson

echo Installing libraries in /usr/local/lib

for l in libblas.so \
	libblas.so.3gf \
	libfftw3.so.3\
	libgfortran.so.3 \
	liblapack.so.3gf \
	libnfft3.so.1 \
	libtcl8.5.so.0; do
  if ldconfig -p | grep -q $l; then
    echo Library $l already exists
  else
    echo Installing library $l
    cp $PLATFORM/$l /usr/local/lib
    chown root:root /usr/local/lib/$l
    chmod ugo+rx /usr/local/lib/$l
  fi
done
echo Rebuilding library path
ldconfig


if [ ! -d /usr/share/tcltk/tcl8.5 ]; then
  echo Installing tcl8.5 in /usr/share/tcltk
  mkdir -p /usr/share/tcltk
  chmod ugo+rX /usr/share/tcltk
  cp -r $PLATFORM/tcl8.5 /usr/share/tcltk
  chown -R root:root /usr/share/tcltk/tcl8.5
  chmod -R ugo+rX /usr/share/tcltk/tcl8.5
fi

if [ ! -d /usr/local/share/simpson ]; then
  echo Making directory /usr/local/share/simpson
  mkdir -p /usr/local/share/simpson
fi

echo Installing simmol in /usr/local
cp noarch/simmol /usr/local/bin
chmod ugo+rwX /usr/local/bin/simmol
cp noarch/simmol.in /usr/local/share/simpson
cp noarch/pkgIndex.tcl /usr/local/share/simpson
cp $PLATFORM/libsimmol.so /usr/local/share/simpson
chmod ugo+rwX /usr/local/share/simpson/libsimmol.so

chown -R root:root /usr/local/share/simpson
chmod -R ugo+rX /usr/local/share/simpson

echo Done

